Documentation Overview
======================

Welcome to the documentation of Nani v\ |version|.


Getting Started
---------------

.. toctree::
   :maxdepth: 2

   overview
   installation
   tutorial


Diving into the Code
--------------------

.. toctree::
   :maxdepth: 2

   reference


Additional Information
----------------------

.. toctree::
   :maxdepth: 1

   contributing
   changes
   versioning
   license


Indices
-------

* :ref:`genindex`


.. testsetup::

   import nani
